==> zither-1.1.13.tar.gz: zither_prj/apollon/user_new.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(1)){
   exit;
   }

$user_name = $_POST["USER"];
$user_pass = $_POST["PASS"];
$user_rev = $_POST["REV"];

if(0 >= strlen($user_name)){
   print("not user name.\n");
   exit;
   }

if(0 >= strlen($user_pass)){
   print("not user pass.\n");
   exit;
   }

if(0 >= strlen($user_rev)){
   print("not user rev.\n");
   exit;
   }

$myutime = date("U");

echo "<HTML>";
echo "<HEAD>";
	echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
	echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--
function WinCls(){
        window.close()
                       }
//     window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</HEAD>";

echo "<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>";
echo "<pre>";



echo "Ȥ뤫ǧ \n";
echo " \n";

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "ǡ١ˤĤʤʤ \n";
   echo "ninsyou_check(): not connection!<br>";
   return -1;
   }

$result = pg_query($conn, "select * from ninsyou where namae = '$user_name';");
if(!$result){
   print("ninsyou_check(): banem select , bud query\n");
   return -1;
   }
$num = pg_num_rows($result);
if($num == 1){
   print("ȤǤˤΤǡUPDATEƤߤޤ \n");
   $result2 = pg_query($conn, "update ninsyou set passw='$user_pass', rev='$user_rev'  where namae='$user_name';");
   if($result2){
      print("ȤUPDATEޤ\n");
      pg_free_result($result2);
      }
   else{
      print("ȤϥåץǡȤ˼Ԥ褦 \n");
      pg_free_result($result2);
      }
   }
else{
   print("Ȥ̵ΤǿäƤߤޤ \n");
   $result3 = pg_query($conn, "INSERT INTO ninsyou VALUES ( '$myutime', '$myutime', '$user_name', '$user_pass', '$user_rev' );");
   if($result3){
      print("ȤϺޤ\n");
      pg_free_result($result3);
      }
   else{
      print("ȤϺ˼Ԥ褦 \n");
      pg_free_result($result3);
      }
   }

pg_free_result($result);
pg_Close($conn);



echo "</pre>";
echo "</body>";

echo "</HTML>";

?>

==> zither-1.1.17.tar.gz: zither_prj/apollon/user_new.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(1)){
   exit;
   }

$user_name = $_POST["USER"];
$user_pass = $_POST["PASS"];
$user_rev = $_POST["REV"];

if(0 >= strlen($user_name)){
   print("not user name.\n");
   exit;
   }

if(0 >= strlen($user_pass)){
   print("not user pass.\n");
   exit;
   }

if(0 >= strlen($user_rev)){
   print("not user rev.\n");
   exit;
   }

$myutime = date("U");

echo "<HTML>";
echo "<HEAD>";
	echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
	echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--
function WinCls(){
        window.close()
                       }
//     window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</HEAD>";

echo "<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>";
echo "<pre>";



echo "Ȥ뤫ǧ \n";
echo " \n";

$conn = db_connect();
if(!$conn){
   echo "ǡ١ˤĤʤʤ \n";
   echo "ninsyou_check(): not connection!<br>";
   return -1;
   }

$result = db_query($conn, "select * from ninsyou where namae = '$user_name';");
if(!$result){
   print("ninsyou_check(): banem select , bud query\n");
   return -1;
   }
$num = db_num_rows($result);
if($num == 1){
   print("ȤǤˤΤǡUPDATEƤߤޤ \n");
   $result2 = db_query($conn, "update ninsyou set passw='$user_pass', rev='$user_rev'  where namae='$user_name';");
   if($result2){
      print("ȤUPDATEޤ\n");
      db_free_result($result2);
      }
   else{
      print("ȤϥåץǡȤ˼Ԥ褦 \n");
      db_free_result($result2);
      }
   }
else{
   print("Ȥ̵ΤǿäƤߤޤ \n");
   $result3 = db_query($conn, "INSERT INTO ninsyou VALUES ( '$myutime', '$myutime', '$user_name', '$user_pass', '$user_rev' );");
   if($result3){
      print("ȤϺޤ\n");
      db_free_result($result3);
      }
   else{
      print("ȤϺ˼Ԥ褦 \n");
      db_free_result($result3);
      }
   }

db_free_result($result);
db_Close($conn);



echo "</pre>";
echo "</body>";

echo "</HTML>";

?>
